import Layout from '@/layout'

const reagentRouter = [
  {
    path: '/reagent',
    hidden: true,
    redirect: '/reagent/mainoverview/index',
    meta: { classification: 'reagent' }
  },
  {
    path: '/reagent/mainoverview',
    component: Layout,
    meta: { classification: 'reagent' },
    children: [
      {
        path: 'index',
        name: 'MainOverview',
        meta: { title: '主预览', icon: '主概览', classification: 'reagent' },
        component: () => import('@/views/reagent/mainoverview/index')
      }
    ]
  },
  {
    path: '/reagent/report',
    component: Layout,
    meta: { classification: 'reagent' },
    children: [
      {
        path: 'index',
        name: 'Report',
        component: () => import('@/views/reagent/report/index'),
        meta: { title: '报告统计', icon: '报表统计', classification: 'reagent' }
      },
      {
        path: 'storeinfo',
        name: 'StoreInfo',
        component: () => import('@/views/reagent/report/storeinfo/index'),
        hidden: true,
        meta: { title: '库存信息总览', icon: '报表统计', classification: 'reagent' }
      },
      {
        path: 'reagentinfo',
        name: 'ReagentInfo',
        component: () => import('@/views/reagent/report/reagentinfo/index'),
        hidden: true,
        meta: { title: '试剂信息详情', icon: '报表统计', classification: 'reagent' }
      },
      {
        path: 'warehousinginfo',
        name: 'WarehousingInfo',
        component: () => import('@/views/reagent/report/warehousinginfo/index'),
        hidden: true,
        meta: { title: '入库信息查询', icon: '报表统计', classification: 'reagent' }
      },
      {
        path: 'inventoryconsuminfo',
        name: 'InventoryConsumInfo',
        component: () => import('@/views/reagent/report/inventoryconsum/index'),
        hidden: true,
        meta: { title: '库存消耗', icon: '报表统计', classification: 'reagent' }
      },
      {
        path: 'reagentconsuminfo',
        name: 'ReagentConsumInfo',
        component: () => import('@/views/reagent/report/reagentconsum/index'),
        hidden: true,
        meta: { title: '试剂消耗', icon: '报表统计', classification: 'reagent' }
      },
      {
        path: 'userconsuminfo',
        name: 'UserConsumInfo',
        component: () => import('@/views/reagent/report/userconsum/index'),
        hidden: true,
        meta: { title: '人员用量消耗', icon: '报表统计', classification: 'reagent' }
      },
      {
        path: 'usefrequencyinfo',
        name: 'UseFrequencyInfo',
        component: () => import('@/views/reagent/report/usefrequency/index'),
        hidden: true,
        meta: { title: '使用频率', icon: '报表统计', classification: 'reagent' }
      },
      {
        path: 'recordinfo/:t',
        name: 'RecordInfo',
        component: () => import('@/views/reagent/report/record/index'),
        hidden: true,
        meta: { title: '记录', icon: '报表统计', classification: 'reagent' }
      }
    ]
  },
  {
    path: '/reagent/warehousing',
    component: Layout,
    meta: { classification: 'reagent' },
    children: [
      {
        path: 'index',
        name: 'Warehousing',
        component: () => import('@/views/reagent/warehousing/index'),
        meta: { title: '试剂入库', icon: '试剂入库', classification: 'reagent' }
      }
    ]
  },
  {
    path: '/reagent/receiving',
    component: Layout,
    meta: { classification: 'reagent' },
    children: [
      {
        path: 'index',
        name: 'Receiving',
        component: () => import('@/views/reagent/receivingandreturn/index'),
        meta: { title: '试剂领用', icon: '试剂领用', classification: 'reagent' }
      }
    ]
  },
  {
    path: '/reagent/sendback',
    component: Layout,
    meta: { classification: 'reagent' },
    children: [
      {
        path: 'index',
        name: 'SendBack',
        component: () => import('@/views/reagent/receivingandreturn/index'),
        meta: { title: '试剂归还', icon: '试剂归还', classification: 'reagent' }
      }
    ]
  },
  {
    path: '/reagent/weighing',
    component: Layout,
    meta: { classification: 'reagent' },
    children: [
      {
        path: 'index',
        name: 'weighing',
        component: () => import('@/views/reagent/weighing/index'),
        meta: { title: '试剂称重', icon: '试剂称重', classification: 'reagent' }
      }
    ]
  },
  {
    path: '/reagent/inventory',
    component: Layout,
    meta: { classification: 'reagent' },
    children: [
      {
        path: 'index',
        name: 'Inventory',
        component: () => import('@/views/reagent/inventory/index'),
        meta: { title: '试剂盘点', icon: '库存盘点', classification: 'reagent' }
      }
    ]
  },
  {
    path: '/reagent/database',
    component: Layout,
    redirect: '/reagent/database/msds',
    meta: { title: '化学品数据库', icon: '化学品数据库', classification: 'reagent' },
    children: [
      {
        path: 'msds',
        name: 'MSDS',
        component: () => import('@/views/reagent/database/index'),
        meta: { title: 'MSDS数据库', classification: 'reagent' }
      },
      {
        path: 'dangerous',
        name: 'Dangerous',
        component: () => import('@/views/reagent/database/index'),
        meta: { title: '危化品数据库', classification: 'reagent' }
      }
    ]
  },
  {
    path: '/reagent/management',
    component: Layout,
    meta: { classification: 'reagent' },
    children: [
      {
        path: 'index',
        name: 'Management',
        component: () => import('@/views/reagent/management/index'),
        meta: { title: '试剂管理', icon: '试剂管理', classification: 'reagent' }
      }
    ]
  },
  {
    path: '/reagent/client',
    component: Layout,
    meta: { classification: 'reagent' },
    children: [
      {
        path: 'index',
        name: 'Client',
        component: () => import('@/views/reagent/client/index'),
        meta: { title: '柜体管理', icon: '柜体管理', classification: 'reagent' }
      }
    ]
  },
  {
    path: '/reagent/envrecord',
    component: Layout,
    meta: { classification: 'reagent' },
    children: [
      {
        path: 'index',
        name: 'EnvRecord',
        component: () => import('@/views/reagent/envrecord/index'),
        meta: { title: '环境记录', icon: '雪花', classification: 'reagent' }
      }
    ]
  },
  {
    path: '/reagent/buy',
    component: Layout,
    meta: { classification: 'reagent' },
    children: [
      {
        path: 'index',
        name: 'Buy',
        component: () => import('@/views/reagent/buy/index'),
        meta: { title: '请购', icon: '请购', classification: 'reagent' }
      }
    ]
  },
  {
    path: '/gotohome',
    redirect: '/home',
    meta: { title: '返回主页', icon: 'el-icon-arrow-left', classification: 'reagent' }
  }
]

export default reagentRouter
